Returns the variance-covariance matrix of the coefficients or the traits.
# S3 method for mvgls
vcov(object, ...)an object of class 'mvgls' obtained from a mvgls fit.
additional arguments for methods function. See details below.
A matrix of the estimated covariances between the parameter estimates (of type "coef", "covariance", or "precision").
The vcov function returns by default the variance-covariance matrix of the main parameters of a fitted model object. The main parameters are the coefficients (this correspond to the argument type="coef"; see also coef.mvgls). With type="covariance", the vcov.mvgls function returns the estimated traits covariance matrix (possibly regularized for PL approaches) while type="precision" return the precision matrix (i.e. the inverse of the covariance).